searchData={"content_type":"text/markdown","items":[{"doc":"Contains functions to add soft delete columns to a table during migrations","ref":"Ecto.SoftDelete.Migration.html","title":"Ecto.SoftDelete.Migration","type":"module"},{"doc":"Adds deleted_at column to a table. This column is used to track if an item is deleted or not and when\n\n    defmodule MyApp.Repo.Migrations.CreateUser do\n      use Ecto.Migration\n      import Ecto.SoftDelete.Migration\n\n      def change do\n        create table(:users) do\n          add :email, :string\n          add :password, :string\n          timestamps()\n          soft_delete_columns()\n        end\n      end\n    end","ref":"Ecto.SoftDelete.Migration.html#soft_delete_columns/0","title":"Ecto.SoftDelete.Migration.soft_delete_columns/0","type":"function"},{"doc":"functions for querying data that is (or is not) soft deleted","ref":"Ecto.SoftDelete.Query.html","title":"Ecto.SoftDelete.Query","type":"module"},{"doc":"Returns `true` if the schema is not flagged to skip auto-filtering","ref":"Ecto.SoftDelete.Query.html#auto_include_deleted_at_clause?/1","title":"Ecto.SoftDelete.Query.auto_include_deleted_at_clause?/1","type":"function"},{"doc":"Returns `true` if the query is soft deletable, `false` otherwise.\n\n    query = from(u in User, select: u)\n    |> soft_deletable?","ref":"Ecto.SoftDelete.Query.html#soft_deletable?/1","title":"Ecto.SoftDelete.Query.soft_deletable?/1","type":"function"},{"doc":"Returns a query that searches only for undeleted items\n\n    query = from(u in User, select: u)\n    |> with_undeleted\n\n    results = Repo.all(query)","ref":"Ecto.SoftDelete.Query.html#with_undeleted/1","title":"Ecto.SoftDelete.Query.with_undeleted/1","type":"function"},{"doc":"Adds soft delete functions to an repository.\n\n    defmodule Repo do\n      use Ecto.Repo,\n        otp_app: :my_app,\n        adapter: Ecto.Adapters.Postgres\n      use Ecto.SoftDelete.Repo\n    end","ref":"Ecto.SoftDelete.Repo.html","title":"Ecto.SoftDelete.Repo","type":"behaviour"},{"doc":"Soft deletes a struct.\nUpdates the `deleted_at` field with the current datetime in UTC.\nIt returns `{:ok, struct}` if the struct has been successfully\nsoft deleted or `{:error, changeset}` if there was a validation\nor a known constraint error.","ref":"Ecto.SoftDelete.Repo.html#c:soft_delete/2","title":"Ecto.SoftDelete.Repo.soft_delete/2","type":"callback"},{"doc":"All options supported by `c:Ecto.Repo.update/2` can be used.","ref":"Ecto.SoftDelete.Repo.html#c:soft_delete/2-options","title":"Options - Ecto.SoftDelete.Repo.soft_delete/2","type":"callback"},{"doc":"post = MyRepo.get!(Post, 42)\n    case MyRepo.soft_delete post do\n      {:ok, struct}       -> # Soft deleted with success\n      {:error, changeset} -> # Something went wrong\n    end\n\n    # With schema prefix for multi-tenant databases\n    MyRepo.soft_delete(post, prefix: \"tenant_abc\")","ref":"Ecto.SoftDelete.Repo.html#c:soft_delete/2-examples","title":"Examples - Ecto.SoftDelete.Repo.soft_delete/2","type":"callback"},{"doc":"Same as `c:soft_delete/2` but returns the struct or raises if the changeset is invalid.","ref":"Ecto.SoftDelete.Repo.html#c:soft_delete!/2","title":"Ecto.SoftDelete.Repo.soft_delete!/2","type":"callback"},{"doc":"Soft deletes all entries matching the given query.\n\nIt returns a tuple containing the number of entries and any returned\nresult as second element. The second element is `nil` by default\nunless a `select` is supplied in the update query.","ref":"Ecto.SoftDelete.Repo.html#c:soft_delete_all/2","title":"Ecto.SoftDelete.Repo.soft_delete_all/2","type":"callback"},{"doc":"All options supported by `c:Ecto.Repo.update_all/3` can be used.","ref":"Ecto.SoftDelete.Repo.html#c:soft_delete_all/2-options","title":"Options - Ecto.SoftDelete.Repo.soft_delete_all/2","type":"callback"},{"doc":"MyRepo.soft_delete_all(Post)\n    from(p in Post, where: p.id   MyRepo.soft_delete_all()\n\n    # With schema prefix for multi-tenant databases\n    MyRepo.soft_delete_all(Post, prefix: \"tenant_abc\")","ref":"Ecto.SoftDelete.Repo.html#c:soft_delete_all/2-examples","title":"Examples - Ecto.SoftDelete.Repo.soft_delete_all/2","type":"callback"},{"doc":"Contains schema macros to add soft delete fields to a schema","ref":"Ecto.SoftDelete.Schema.html","title":"Ecto.SoftDelete.Schema","type":"module"},{"doc":"Adds the deleted_at column to a schema\n\n    defmodule User do\n      use Ecto.Schema\n      import Ecto.SoftDelete.Schema\n\n      schema \"users\" do\n        field :email, :string\n        soft_delete_schema()\n      end\n    end\n\nOptions:\n- `:auto_exclude_from_queries?` - If false, Ecto.SoftDelete.Repo won't\nautomatically add the necessary clause to filter out soft-deleted rows. See\n`Ecto.SoftDelete.Repo.prepare_query` for more info. Defaults to `true`.","ref":"Ecto.SoftDelete.Schema.html#soft_delete_schema/1","title":"Ecto.SoftDelete.Schema.soft_delete_schema/1","type":"macro"}]}